@@ -1,4 +1,3 @@
-
 /********************************************
 main.c
 copyright 1991, Michael D. Brennan
@@ -10,7 +9,9 @@ Mawk is distributed without warranty under the terms of
 the GNU General Public License, version 2, 1991.
 ********************************************/
 
-/* @Log: main.c,v @
+/*
+ * $MawkId: main.c,v 1.8 2009/12/14 00:23:56 tom Exp $
+ * @Log: main.c,v @
  * Revision 1.4  1995/06/09  22:57:19  mike
  * parse() no longer returns on error
  *
@@ -38,62 +39,55 @@ the GNU General Public License, version 2, 1991.
  * Revision 5.1	 1991/12/05  07:56:14  brennan
  * 1.1 pre-release
  *
-*/
-
-
+ */
 
 /*  main.c  */
 
-#ifndef LOCAL_REGEXP
-#		include <locale.h>
-#endif
-
 #include "mawk.h"
 #include "init.h"
 #include "code.h"
 #include "files.h"
 
+#ifdef LOCALE
+#include <locale.h>
+#endif
 
-short mawk_state ;		 /* 0 is compiling */
-int exit_code ;
+short mawk_state;		/* 0 is compiling */
+int exit_code;
 
-static void initialize_locale (void)
+static void
+initialize_locale(void)
 {
-#ifndef LOCAL_REGEXP
-   setlocale(LC_CTYPE, "");
-   setlocale(LC_COLLATE, "");
-   setlocale(LC_MESSAGES, "");
-   setlocale(LC_NUMERIC, "C");
-   setlocale(LC_TIME, "");
+#ifdef LOCALE
+    setlocale(LC_CTYPE, "");
+    setlocale(LC_NUMERIC, "C");
 #endif
 }
 
 int
-main(argc, argv)
-int argc ; char **argv ;
+main(int argc, char **argv)
 {
-   initialize_locale ();
-   initialize(argc, argv) ;
+    initialize_locale();
+    initialize(argc, argv);
 
-   parse() ;
+    parse();
 
-   mawk_state = EXECUTION ;
-   execute(execution_start, eval_stack - 1, 0) ;
-   /* never returns */
-   return 0 ;
+    mawk_state = EXECUTION;
+    execute(execution_start, eval_stack - 1, 0);
+    /* never returns */
+    return 0;
 }
 
 void
-mawk_exit(x)
-   int x ;
+mawk_exit(int x)
 {
 #ifdef  HAVE_REAL_PIPES
-   close_out_pipes() ;		 /* no effect, if no out pipes */
+    close_out_pipes();		/* no effect, if no out pipes */
 #else
 #ifdef  HAVE_FAKE_PIPES
-   close_fake_pipes() ;
+    close_fake_pipes();
 #endif
 #endif
 
-   exit(x) ;
+    exit(x);
 }
