@@ -9,8 +9,9 @@ Mawk is distributed without warranty under the terms of
 the GNU General Public License, version 2, 1991.
 ********************************************/
 
-
-/* @Log: memory.h,v @
+/*
+ * $MawkId: memory.h,v 1.6 2009/07/27 15:14:56 tom Exp $
+ * @Log: memory.h,v @
  * Revision 1.1.1.1  1993/07/03  18:58:17  mike
  * move source to cvs
  *
@@ -24,16 +25,18 @@ the GNU General Public License, version 2, 1991.
 
 /*  memory.h  */
 
-#ifndef  MEMORY_H
-#define  MEMORY_H
+#ifndef  MAWK_MEMORY_H
+#define  MAWK_MEMORY_H
 
+#include "types.h"
 #include "zmalloc.h"
 
-STRING *new_STRING(char*);
+STRING *new_STRING(const char *);
 STRING *new_STRING0(unsigned);
+STRING *new_STRING1(const char *, unsigned);
 
 #ifdef   DEBUG
-void  DB_free_STRING(STRING *);
+void DB_free_STRING(STRING *);
 
 #define  free_STRING(s)  DB_free_STRING(s)
 
@@ -46,4 +49,4 @@ void  DB_free_STRING(STRING *);
 	    } while (0)
 #endif
 
-#endif   /* MEMORY_H */
+#endif /* MAWK_MEMORY_H */
