@@ -8,7 +8,7 @@ static const char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
-#define YYPATCH 20090221
+#define YYPATCH 20091027
 
 #define YYEMPTY        (-1)
 #define yyclearin      (yychar = YYEMPTY)
@@ -31,7 +31,7 @@ extern int YYPARSE_DECL();
 
 static int yygrowstack(void);
 #define YYPREFIX "yy"
-#line 79 "parse.y"
+#line 81 "parse.y"
 #include <stdio.h>
 #include "mawk.h"
 #include "symtype.h"
@@ -47,15 +47,15 @@ static int yygrowstack(void);
 #define  YYMAXDEPTH	200
 
 
-extern void  PROTO( eat_nl, (void) ) ;
-static void  PROTO( resize_fblock, (FBLOCK *) ) ;
-static void  PROTO( switch_code_to_main, (void)) ;
-static void  PROTO( code_array, (SYMTAB *) ) ;
-static void  PROTO( code_call_id, (CA_REC *, SYMTAB *) ) ;
-static void  PROTO( field_A2I, (void)) ;
-static void  PROTO( check_var, (SYMTAB *) ) ;
-static void  PROTO( check_array, (SYMTAB *) ) ;
-static void  PROTO( RE_as_arg, (void)) ;
+extern void eat_nl (void) ;
+static void resize_fblock (FBLOCK *) ;
+static void switch_code_to_main (void) ;
+static void code_array (SYMTAB *) ;
+static void code_call_id (CA_REC *, SYMTAB *) ;
+static void field_A2I (void) ;
+static void check_var (SYMTAB *) ;
+static void check_array (SYMTAB *) ;
+static void RE_as_arg (void) ;
 
 static int scope ;
 static FBLOCK *active_funct ;
@@ -74,7 +74,7 @@ static FBLOCK *active_funct ;
 /* this nonsense caters to MSDOS large model */
 #define  CODE_FE_PUSHA()  code_ptr->ptr = (PTR) 0 ; code1(FE_PUSHA)
 
-#line 123 "parse.y"
+#line 125 "parse.y"
 typedef union{
 CELL *cp ;
 SYMTAB *stp ;
@@ -1146,7 +1146,7 @@ static short   *yyss;
 static short   *yysslim;
 static YYSTYPE *yyvs;
 static unsigned yystacksize;
-#line 1147 "parse.y"
+#line 1148 "parse.y"
 
 /* resize the code for a user function */
 
@@ -1570,37 +1570,37 @@ yyreduce:
     switch (yyn)
     {
 case 6:
-#line 209 "parse.y"
+#line 211 "parse.y"
 	{ /* this do nothing action removes a vacuous warning
                   from Bison */
              }
 break;
 case 7:
-#line 214 "parse.y"
+#line 216 "parse.y"
 	{ be_setup(scope = SCOPE_BEGIN) ; }
 break;
 case 8:
-#line 217 "parse.y"
+#line 219 "parse.y"
 	{ switch_code_to_main() ; }
 break;
 case 9:
-#line 220 "parse.y"
+#line 222 "parse.y"
 	{ be_setup(scope = SCOPE_END) ; }
 break;
 case 10:
-#line 223 "parse.y"
+#line 225 "parse.y"
 	{ switch_code_to_main() ; }
 break;
 case 11:
-#line 226 "parse.y"
+#line 228 "parse.y"
 	{ code_jmp(_JZ, (INST*)0) ; }
 break;
 case 12:
-#line 229 "parse.y"
+#line 231 "parse.y"
 	{ patch_jmp( code_ptr ) ; }
 break;
 case 13:
-#line 233 "parse.y"
+#line 235 "parse.y"
 	{
                INST *p1 = CDP(yyvsp[-1].start) ;
              int len ;
@@ -1618,11 +1618,11 @@ case 13:
              }
 break;
 case 14:
-#line 249 "parse.y"
+#line 251 "parse.y"
 	{ code1(_STOP) ; }
 break;
 case 15:
-#line 252 "parse.y"
+#line 254 "parse.y"
 	{
                INST *p1 = CDP(yyvsp[-5].start) ;
 
@@ -1631,32 +1631,32 @@ case 15:
              }
 break;
 case 16:
-#line 263 "parse.y"
+#line 265 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; }
 break;
 case 17:
-#line 265 "parse.y"
+#line 267 "parse.y"
 	{ yyval.start = code_offset ; /* does nothing won't be executed */
               print_flag = getline_flag = paren_cnt = 0 ;
               yyerrok ; }
 break;
 case 19:
-#line 272 "parse.y"
+#line 274 "parse.y"
 	{ yyval.start = code_offset ;
                        code1(_PUSHINT) ; code1(0) ;
                        code2(_PRINT, bi_print) ;
                      }
 break;
 case 23:
-#line 285 "parse.y"
+#line 287 "parse.y"
 	{ code1(_POP) ; }
 break;
 case 24:
-#line 287 "parse.y"
+#line 289 "parse.y"
 	{ yyval.start = code_offset ; }
 break;
 case 25:
-#line 289 "parse.y"
+#line 291 "parse.y"
 	{ yyval.start = code_offset ;
                 print_flag = getline_flag = 0 ;
                 paren_cnt = 0 ;
@@ -1664,23 +1664,23 @@ case 25:
               }
 break;
 case 26:
-#line 295 "parse.y"
+#line 297 "parse.y"
 	{ yyval.start = code_offset ; BC_insert('B', code_ptr+1) ;
                code2(_JMP, 0) /* don't use code_jmp ! */ ; }
 break;
 case 27:
-#line 298 "parse.y"
+#line 300 "parse.y"
 	{ yyval.start = code_offset ; BC_insert('C', code_ptr+1) ;
                code2(_JMP, 0) ; }
 break;
 case 28:
-#line 301 "parse.y"
+#line 303 "parse.y"
 	{ if ( scope != SCOPE_FUNCT )
                      compile_error("return outside function body") ;
              }
 break;
 case 29:
-#line 305 "parse.y"
+#line 307 "parse.y"
 	{ if ( scope != SCOPE_MAIN )
                    compile_error( "improper use of next" ) ;
                 yyval.start = code_offset ;
@@ -1688,59 +1688,59 @@ case 29:
               }
 break;
 case 33:
-#line 316 "parse.y"
+#line 318 "parse.y"
 	{ code1(_ASSIGN) ; }
 break;
 case 34:
-#line 317 "parse.y"
+#line 319 "parse.y"
 	{ code1(_ADD_ASG) ; }
 break;
 case 35:
-#line 318 "parse.y"
+#line 320 "parse.y"
 	{ code1(_SUB_ASG) ; }
 break;
 case 36:
-#line 319 "parse.y"
+#line 321 "parse.y"
 	{ code1(_MUL_ASG) ; }
 break;
 case 37:
-#line 320 "parse.y"
+#line 322 "parse.y"
 	{ code1(_DIV_ASG) ; }
 break;
 case 38:
-#line 321 "parse.y"
+#line 323 "parse.y"
 	{ code1(_MOD_ASG) ; }
 break;
 case 39:
-#line 322 "parse.y"
+#line 324 "parse.y"
 	{ code1(_POW_ASG) ; }
 break;
 case 40:
-#line 323 "parse.y"
+#line 325 "parse.y"
 	{ code1(_EQ) ; }
 break;
 case 41:
-#line 324 "parse.y"
+#line 326 "parse.y"
 	{ code1(_NEQ) ; }
 break;
 case 42:
-#line 325 "parse.y"
+#line 327 "parse.y"
 	{ code1(_LT) ; }
 break;
 case 43:
-#line 326 "parse.y"
+#line 328 "parse.y"
 	{ code1(_LTE) ; }
 break;
 case 44:
-#line 327 "parse.y"
+#line 329 "parse.y"
 	{ code1(_GT) ; }
 break;
 case 45:
-#line 328 "parse.y"
+#line 330 "parse.y"
 	{ code1(_GTE) ; }
 break;
 case 46:
-#line 331 "parse.y"
+#line 333 "parse.y"
 	{
             INST *p3 = CDP(yyvsp[0].start) ;
 
@@ -1767,51 +1767,51 @@ case 46:
           }
 break;
 case 47:
-#line 358 "parse.y"
+#line 360 "parse.y"
 	{ code1(_TEST) ;
                 code_jmp(_LJNZ, (INST*)0) ;
               }
 break;
 case 48:
-#line 362 "parse.y"
+#line 364 "parse.y"
 	{ code1(_TEST) ; patch_jmp(code_ptr) ; }
 break;
 case 49:
-#line 365 "parse.y"
+#line 367 "parse.y"
 	{ code1(_TEST) ;
                 code_jmp(_LJZ, (INST*)0) ;
               }
 break;
 case 50:
-#line 369 "parse.y"
+#line 371 "parse.y"
 	{ code1(_TEST) ; patch_jmp(code_ptr) ; }
 break;
 case 51:
-#line 371 "parse.y"
+#line 373 "parse.y"
 	{ code_jmp(_JZ, (INST*)0) ; }
 break;
 case 52:
-#line 372 "parse.y"
+#line 374 "parse.y"
 	{ code_jmp(_JMP, (INST*)0) ; }
 break;
 case 53:
-#line 374 "parse.y"
+#line 376 "parse.y"
 	{ patch_jmp(code_ptr) ; patch_jmp(CDP(yyvsp[0].start)) ; }
 break;
 case 55:
-#line 379 "parse.y"
+#line 381 "parse.y"
 	{ code1(_CAT) ; }
 break;
 case 56:
-#line 383 "parse.y"
+#line 385 "parse.y"
 	{  yyval.start = code_offset ; code2(_PUSHD, yyvsp[0].ptr) ; }
 break;
 case 57:
-#line 385 "parse.y"
+#line 387 "parse.y"
 	{ yyval.start = code_offset ; code2(_PUSHS, yyvsp[0].ptr) ; }
 break;
 case 58:
-#line 387 "parse.y"
+#line 389 "parse.y"
 	{ check_var(yyvsp[0].stp) ;
             yyval.start = code_offset ;
             if ( is_local(yyvsp[0].stp) )
@@ -1820,51 +1820,51 @@ case 58:
           }
 break;
 case 59:
-#line 395 "parse.y"
+#line 397 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; }
 break;
 case 60:
-#line 399 "parse.y"
+#line 401 "parse.y"
 	{ yyval.start = code_offset ; code2(_MATCH0, yyvsp[0].ptr) ; }
 break;
 case 61:
-#line 402 "parse.y"
+#line 404 "parse.y"
 	{ code1(_ADD) ; }
 break;
 case 62:
-#line 403 "parse.y"
+#line 405 "parse.y"
 	{ code1(_SUB) ; }
 break;
 case 63:
-#line 404 "parse.y"
+#line 406 "parse.y"
 	{ code1(_MUL) ; }
 break;
 case 64:
-#line 405 "parse.y"
+#line 407 "parse.y"
 	{ code1(_DIV) ; }
 break;
 case 65:
-#line 406 "parse.y"
+#line 408 "parse.y"
 	{ code1(_MOD) ; }
 break;
 case 66:
-#line 407 "parse.y"
+#line 409 "parse.y"
 	{ code1(_POW) ; }
 break;
 case 67:
-#line 409 "parse.y"
+#line 411 "parse.y"
 	{ yyval.start = yyvsp[0].start ; code1(_NOT) ; }
 break;
 case 68:
-#line 411 "parse.y"
+#line 413 "parse.y"
 	{ yyval.start = yyvsp[0].start ; code1(_UPLUS) ; }
 break;
 case 69:
-#line 413 "parse.y"
+#line 415 "parse.y"
 	{ yyval.start = yyvsp[0].start ; code1(_UMINUS) ; }
 break;
 case 71:
-#line 418 "parse.y"
+#line 420 "parse.y"
 	{ check_var(yyvsp[-1].stp) ;
              yyval.start = code_offset ;
              code_address(yyvsp[-1].stp) ;
@@ -1874,46 +1874,46 @@ case 71:
            }
 break;
 case 72:
-#line 426 "parse.y"
+#line 428 "parse.y"
 	{ yyval.start = yyvsp[0].start ;
               if ( yyvsp[-1].ival == '+' ) code1(_PRE_INC) ;
               else  code1(_PRE_DEC) ;
             }
 break;
 case 73:
-#line 433 "parse.y"
+#line 435 "parse.y"
 	{ if (yyvsp[0].ival == '+' ) code1(F_POST_INC ) ;
              else  code1(F_POST_DEC) ;
            }
 break;
 case 74:
-#line 437 "parse.y"
+#line 439 "parse.y"
 	{ yyval.start = yyvsp[0].start ;
              if ( yyvsp[-1].ival == '+' ) code1(F_PRE_INC) ;
              else  code1( F_PRE_DEC) ;
            }
 break;
 case 75:
-#line 444 "parse.y"
+#line 446 "parse.y"
 	{ yyval.start = code_offset ;
           check_var(yyvsp[0].stp) ;
           code_address(yyvsp[0].stp) ;
         }
 break;
 case 76:
-#line 452 "parse.y"
+#line 454 "parse.y"
 	{ yyval.ival = 0 ; }
 break;
 case 78:
-#line 457 "parse.y"
+#line 459 "parse.y"
 	{ yyval.ival = 1 ; }
 break;
 case 79:
-#line 459 "parse.y"
+#line 461 "parse.y"
 	{ yyval.ival = yyvsp[-2].ival + 1 ; }
 break;
 case 80:
-#line 464 "parse.y"
+#line 466 "parse.y"
 	{ BI_REC *p = yyvsp[-4].bip ;
           yyval.start = yyvsp[-3].start ;
           if ( (int)p->min_args > yyvsp[-1].ival || (int)p->max_args < yyvsp[-1].ival )
@@ -1926,7 +1926,7 @@ case 80:
         }
 break;
 case 81:
-#line 475 "parse.y"
+#line 477 "parse.y"
 	{
             yyval.start = code_offset ;
             code1(_PUSHINT) ; code1(0) ;
@@ -1934,11 +1934,11 @@ case 81:
           }
 break;
 case 82:
-#line 484 "parse.y"
+#line 486 "parse.y"
 	{ yyval.start = code_offset ; }
 break;
 case 83:
-#line 489 "parse.y"
+#line 491 "parse.y"
 	{ code2(_PRINT, yyvsp[-4].fp) ;
               if ( yyvsp[-4].fp == bi_printf && yyvsp[-2].ival == 0 )
                     compile_error("no arguments in call to printf") ;
@@ -1947,72 +1947,72 @@ case 83:
             }
 break;
 case 84:
-#line 497 "parse.y"
+#line 499 "parse.y"
 	{ yyval.fp = bi_print ; print_flag = 1 ;}
 break;
 case 85:
-#line 498 "parse.y"
+#line 500 "parse.y"
 	{ yyval.fp = bi_printf ; print_flag = 1 ; }
 break;
 case 86:
-#line 501 "parse.y"
+#line 503 "parse.y"
 	{ code2op(_PUSHINT, yyvsp[0].ival) ; }
 break;
 case 87:
-#line 503 "parse.y"
+#line 505 "parse.y"
 	{ yyval.ival = yyvsp[-1].arg2p->cnt ; zfree(yyvsp[-1].arg2p,sizeof(ARG2_REC)) ;
              code2op(_PUSHINT, yyval.ival) ;
            }
 break;
 case 88:
-#line 507 "parse.y"
+#line 509 "parse.y"
 	{ yyval.ival=0 ; code2op(_PUSHINT, 0) ; }
 break;
 case 89:
-#line 511 "parse.y"
+#line 513 "parse.y"
 	{ yyval.arg2p = (ARG2_REC*) zmalloc(sizeof(ARG2_REC)) ;
              yyval.arg2p->start = yyvsp[-2].start ;
              yyval.arg2p->cnt = 2 ;
            }
 break;
 case 90:
-#line 516 "parse.y"
+#line 518 "parse.y"
 	{ yyval.arg2p = yyvsp[-2].arg2p ; yyval.arg2p->cnt++ ; }
 break;
 case 92:
-#line 521 "parse.y"
+#line 523 "parse.y"
 	{ code2op(_PUSHINT, yyvsp[-1].ival) ; }
 break;
 case 93:
-#line 528 "parse.y"
+#line 530 "parse.y"
 	{  yyval.start = yyvsp[-1].start ; eat_nl() ; code_jmp(_JZ, (INST*)0) ; }
 break;
 case 94:
-#line 533 "parse.y"
+#line 535 "parse.y"
 	{ patch_jmp( code_ptr ) ;  }
 break;
 case 95:
-#line 536 "parse.y"
+#line 538 "parse.y"
 	{ eat_nl() ; code_jmp(_JMP, (INST*)0) ; }
 break;
 case 96:
-#line 541 "parse.y"
+#line 543 "parse.y"
 	{ patch_jmp(code_ptr) ;
                   patch_jmp(CDP(yyvsp[0].start)) ;
                 }
 break;
 case 97:
-#line 550 "parse.y"
+#line 552 "parse.y"
 	{ eat_nl() ; BC_new() ; }
 break;
 case 98:
-#line 555 "parse.y"
+#line 557 "parse.y"
 	{ yyval.start = yyvsp[-5].start ;
           code_jmp(_JNZ, CDP(yyvsp[-5].start)) ;
           BC_clear(code_ptr, CDP(yyvsp[-2].start)) ; }
 break;
 case 99:
-#line 561 "parse.y"
+#line 563 "parse.y"
 	{ eat_nl() ; BC_new() ;
                   yyval.start = yyvsp[-1].start ;
 
@@ -2031,7 +2031,7 @@ case 99:
                 }
 break;
 case 100:
-#line 581 "parse.y"
+#line 583 "parse.y"
 	{
                   int  saved_offset ;
                   int len ;
@@ -2055,7 +2055,7 @@ case 100:
                 }
 break;
 case 101:
-#line 607 "parse.y"
+#line 609 "parse.y"
 	{
                   int cont_offset = code_offset ;
                   unsigned len = code_pop(code_ptr) ;
@@ -2079,19 +2079,19 @@ case 101:
                 }
 break;
 case 102:
-#line 630 "parse.y"
+#line 632 "parse.y"
 	{ yyval.start = code_offset ; }
 break;
 case 103:
-#line 632 "parse.y"
+#line 634 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; code1(_POP) ; }
 break;
 case 104:
-#line 635 "parse.y"
+#line 637 "parse.y"
 	{ yyval.start = code_offset ; }
 break;
 case 105:
-#line 637 "parse.y"
+#line 639 "parse.y"
 	{
              if ( code_ptr - 2 == CDP(yyvsp[-1].start) &&
                   code_ptr[-2].op == _PUSHD &&
@@ -2108,13 +2108,13 @@ case 105:
            }
 break;
 case 106:
-#line 654 "parse.y"
+#line 656 "parse.y"
 	{ eat_nl() ; BC_new() ;
              code_push((INST*)0,0, scope, active_funct) ;
            }
 break;
 case 107:
-#line 658 "parse.y"
+#line 660 "parse.y"
 	{ INST *p1 = CDP(yyvsp[-1].start) ;
 
              eat_nl() ; BC_new() ;
@@ -2124,14 +2124,14 @@ case 107:
            }
 break;
 case 108:
-#line 671 "parse.y"
+#line 673 "parse.y"
 	{ check_array(yyvsp[0].stp) ;
              code_array(yyvsp[0].stp) ;
              code1(A_TEST) ;
             }
 break;
 case 109:
-#line 676 "parse.y"
+#line 678 "parse.y"
 	{ yyval.start = yyvsp[-3].arg2p->start ;
              code2op(A_CAT, yyvsp[-3].arg2p->cnt) ;
              zfree(yyvsp[-3].arg2p, sizeof(ARG2_REC)) ;
@@ -2142,7 +2142,7 @@ case 109:
            }
 break;
 case 110:
-#line 687 "parse.y"
+#line 689 "parse.y"
 	{
              if ( yyvsp[-1].ival > 1 )
              { code2op(A_CAT, yyvsp[-1].ival) ; }
@@ -2155,7 +2155,7 @@ case 110:
            }
 break;
 case 111:
-#line 700 "parse.y"
+#line 702 "parse.y"
 	{
              if ( yyvsp[-1].ival > 1 )
              { code2op(A_CAT, yyvsp[-1].ival) ; }
@@ -2168,7 +2168,7 @@ case 111:
            }
 break;
 case 112:
-#line 712 "parse.y"
+#line 714 "parse.y"
 	{
              if ( yyvsp[-2].ival > 1 )
              { code2op(A_CAT,yyvsp[-2].ival) ; }
@@ -2184,7 +2184,7 @@ case 112:
            }
 break;
 case 113:
-#line 729 "parse.y"
+#line 731 "parse.y"
 	{
                yyval.start = yyvsp[-4].start ;
                if ( yyvsp[-2].ival > 1 ) { code2op(A_CAT, yyvsp[-2].ival) ; }
@@ -2194,7 +2194,7 @@ case 113:
              }
 break;
 case 114:
-#line 737 "parse.y"
+#line 739 "parse.y"
 	{
                 yyval.start = code_offset ;
                 check_array(yyvsp[-1].stp) ;
@@ -2203,7 +2203,7 @@ case 114:
              }
 break;
 case 115:
-#line 748 "parse.y"
+#line 750 "parse.y"
 	{ eat_nl() ; BC_new() ;
                       yyval.start = code_offset ;
 
@@ -2216,7 +2216,7 @@ case 115:
                     }
 break;
 case 116:
-#line 762 "parse.y"
+#line 764 "parse.y"
 	{
                 INST *p2 = CDP(yyvsp[0].start) ;
 
@@ -2227,11 +2227,11 @@ case 116:
               }
 break;
 case 117:
-#line 779 "parse.y"
+#line 781 "parse.y"
 	{ yyval.start = code_offset ; code2(F_PUSHA, yyvsp[0].cp) ; }
 break;
 case 118:
-#line 781 "parse.y"
+#line 783 "parse.y"
 	{ check_var(yyvsp[0].stp) ;
              yyval.start = code_offset ;
              if ( is_local(yyvsp[0].stp) )
@@ -2242,7 +2242,7 @@ case 118:
            }
 break;
 case 119:
-#line 790 "parse.y"
+#line 792 "parse.y"
 	{
              if ( yyvsp[-1].ival > 1 )
              { code2op(A_CAT, yyvsp[-1].ival) ; }
@@ -2258,62 +2258,62 @@ case 119:
            }
 break;
 case 120:
-#line 804 "parse.y"
+#line 806 "parse.y"
 	{ yyval.start = yyvsp[0].start ;  CODE_FE_PUSHA() ; }
 break;
 case 121:
-#line 806 "parse.y"
+#line 808 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; }
 break;
 case 122:
-#line 810 "parse.y"
+#line 812 "parse.y"
 	{ field_A2I() ; }
 break;
 case 123:
-#line 813 "parse.y"
+#line 815 "parse.y"
 	{ code1(F_ASSIGN) ; }
 break;
 case 124:
-#line 814 "parse.y"
+#line 816 "parse.y"
 	{ code1(F_ADD_ASG) ; }
 break;
 case 125:
-#line 815 "parse.y"
+#line 817 "parse.y"
 	{ code1(F_SUB_ASG) ; }
 break;
 case 126:
-#line 816 "parse.y"
+#line 818 "parse.y"
 	{ code1(F_MUL_ASG) ; }
 break;
 case 127:
-#line 817 "parse.y"
+#line 819 "parse.y"
 	{ code1(F_DIV_ASG) ; }
 break;
 case 128:
-#line 818 "parse.y"
+#line 820 "parse.y"
 	{ code1(F_MOD_ASG) ; }
 break;
 case 129:
-#line 819 "parse.y"
+#line 821 "parse.y"
 	{ code1(F_POW_ASG) ; }
 break;
 case 130:
-#line 826 "parse.y"
+#line 828 "parse.y"
 	{ code2(_BUILTIN, bi_split) ; }
 break;
 case 131:
-#line 830 "parse.y"
+#line 832 "parse.y"
 	{ yyval.start = yyvsp[-2].start ;
               check_array(yyvsp[0].stp) ;
               code_array(yyvsp[0].stp)  ;
             }
 break;
 case 132:
-#line 837 "parse.y"
+#line 839 "parse.y"
 	{ code2(_PUSHI, &fs_shadow) ; }
 break;
 case 133:
-#line 839 "parse.y"
+#line 841 "parse.y"
 	{
                   if ( CDP(yyvsp[-1].start) == code_ptr - 2 )
                   {
@@ -2333,13 +2333,13 @@ case 133:
                 }
 break;
 case 134:
-#line 863 "parse.y"
+#line 865 "parse.y"
 	{ yyval.start = yyvsp[-3].start ;
           code2(_BUILTIN, bi_match) ;
         }
 break;
 case 135:
-#line 870 "parse.y"
+#line 872 "parse.y"
 	{
                INST *p1 = CDP(yyvsp[0].start) ;
 
@@ -2360,25 +2360,25 @@ case 135:
              }
 break;
 case 136:
-#line 893 "parse.y"
+#line 895 "parse.y"
 	{ yyval.start = code_offset ;
                       code1(_EXIT0) ; }
 break;
 case 137:
-#line 896 "parse.y"
+#line 898 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; code1(_EXIT) ; }
 break;
 case 138:
-#line 900 "parse.y"
+#line 902 "parse.y"
 	{ yyval.start = code_offset ;
                       code1(_RET0) ; }
 break;
 case 139:
-#line 903 "parse.y"
+#line 905 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; code1(_RET) ; }
 break;
 case 140:
-#line 909 "parse.y"
+#line 911 "parse.y"
 	{ yyval.start = code_offset ;
             code2(F_PUSHA, &field[0]) ;
             code1(_PUSHINT) ; code1(0) ;
@@ -2387,7 +2387,7 @@ case 140:
           }
 break;
 case 141:
-#line 916 "parse.y"
+#line 918 "parse.y"
 	{ yyval.start = yyvsp[0].start ;
             code1(_PUSHINT) ; code1(0) ;
             code2(_BUILTIN, bi_getline) ;
@@ -2395,42 +2395,42 @@ case 141:
           }
 break;
 case 142:
-#line 922 "parse.y"
+#line 924 "parse.y"
 	{ code1(_PUSHINT) ; code1(F_IN) ;
             code2(_BUILTIN, bi_getline) ;
             /* getline_flag already off in yylex() */
           }
 break;
 case 143:
-#line 927 "parse.y"
+#line 929 "parse.y"
 	{ code2(F_PUSHA, &field[0]) ;
             code1(_PUSHINT) ; code1(PIPE_IN) ;
             code2(_BUILTIN, bi_getline) ;
           }
 break;
 case 144:
-#line 932 "parse.y"
+#line 934 "parse.y"
 	{
             code1(_PUSHINT) ; code1(PIPE_IN) ;
             code2(_BUILTIN, bi_getline) ;
           }
 break;
 case 145:
-#line 938 "parse.y"
+#line 940 "parse.y"
 	{ getline_flag = 1 ; }
 break;
 case 148:
-#line 943 "parse.y"
+#line 945 "parse.y"
 	{ yyval.start = code_offset ;
                    code2(F_PUSHA, field+0) ;
                  }
 break;
 case 149:
-#line 947 "parse.y"
+#line 949 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; }
 break;
 case 150:
-#line 955 "parse.y"
+#line 957 "parse.y"
 	{
              INST *p5 = CDP(yyvsp[-1].start) ;
              INST *p6 = CDP(yyvsp[0].start) ;
@@ -2449,25 +2449,25 @@ case 150:
            }
 break;
 case 151:
-#line 973 "parse.y"
+#line 975 "parse.y"
 	{ yyval.fp = bi_sub ; }
 break;
 case 152:
-#line 974 "parse.y"
+#line 976 "parse.y"
 	{ yyval.fp = bi_gsub ; }
 break;
 case 153:
-#line 979 "parse.y"
+#line 981 "parse.y"
 	{ yyval.start = code_offset ;
                   code2(F_PUSHA, &field[0]) ;
                 }
 break;
 case 154:
-#line 984 "parse.y"
+#line 986 "parse.y"
 	{ yyval.start = yyvsp[-1].start ; }
 break;
 case 155:
-#line 992 "parse.y"
+#line 994 "parse.y"
 	{
                    resize_fblock(yyvsp[-1].fbp) ;
                    restore_ids() ;
@@ -2475,7 +2475,7 @@ case 155:
                  }
 break;
 case 156:
-#line 1001 "parse.y"
+#line 1003 "parse.y"
 	{ eat_nl() ;
                    scope = SCOPE_FUNCT ;
                    active_funct = yyvsp[-3].fbp ;
@@ -2494,7 +2494,7 @@ case 156:
                  }
 break;
 case 157:
-#line 1020 "parse.y"
+#line 1022 "parse.y"
 	{ FBLOCK  *fbp ;
 
                    if ( yyvsp[0].stp->type == ST_NONE )
@@ -2518,18 +2518,18 @@ case 157:
                  }
 break;
 case 158:
-#line 1043 "parse.y"
+#line 1045 "parse.y"
 	{ yyval.fbp = yyvsp[0].fbp ;
                    if ( yyvsp[0].fbp->code )
                        compile_error("redefinition of %s" , yyvsp[0].fbp->name) ;
                  }
 break;
 case 159:
-#line 1049 "parse.y"
+#line 1051 "parse.y"
 	{ yyval.ival = 0 ; }
 break;
 case 161:
-#line 1054 "parse.y"
+#line 1056 "parse.y"
 	{ yyvsp[0].stp = save_id(yyvsp[0].stp->name) ;
                 yyvsp[0].stp->type = ST_LOCAL_NONE ;
                 yyvsp[0].stp->offset = 0 ;
@@ -2537,7 +2537,7 @@ case 161:
               }
 break;
 case 162:
-#line 1060 "parse.y"
+#line 1062 "parse.y"
 	{ if ( is_local(yyvsp[0].stp) )
                   compile_error("%s is duplicated in argument list",
                     yyvsp[0].stp->name) ;
@@ -2550,7 +2550,7 @@ case 162:
               }
 break;
 case 163:
-#line 1073 "parse.y"
+#line 1075 "parse.y"
 	{  /* we may have to recover from a bungled function
                        definition */
                    /* can have local ids, before code scope
@@ -2561,34 +2561,33 @@ case 163:
                  }
 break;
 case 164:
-#line 1086 "parse.y"
+#line 1088 "parse.y"
 	{ yyval.start = yyvsp[-1].start ;
              code2(_CALL, yyvsp[-2].fbp) ;
 
              if ( yyvsp[0].ca_p )  code1(yyvsp[0].ca_p->arg_num+1) ;
              else  code1(0) ;
 
-             check_fcall(yyvsp[-2].fbp, scope, code_move_level, active_funct,
-                         yyvsp[0].ca_p, token_lineno) ;
+             check_fcall(yyvsp[-2].fbp, scope, code_move_level, active_funct, yyvsp[0].ca_p) ;
            }
 break;
 case 165:
-#line 1098 "parse.y"
+#line 1099 "parse.y"
 	{ yyval.ca_p = (CA_REC *) 0 ; }
 break;
 case 166:
-#line 1100 "parse.y"
+#line 1101 "parse.y"
 	{ yyval.ca_p = yyvsp[0].ca_p ;
                  yyval.ca_p->link = yyvsp[-1].ca_p ;
                  yyval.ca_p->arg_num = yyvsp[-1].ca_p ? yyvsp[-1].ca_p->arg_num+1 : 0 ;
                }
 break;
 case 167:
-#line 1115 "parse.y"
+#line 1116 "parse.y"
 	{ yyval.ca_p = (CA_REC *) 0 ; }
 break;
 case 168:
-#line 1117 "parse.y"
+#line 1118 "parse.y"
 	{ yyval.ca_p = ZMALLOC(CA_REC) ;
                 yyval.ca_p->link = yyvsp[-2].ca_p ;
                 yyval.ca_p->type = CA_EXPR  ;
@@ -2597,7 +2596,7 @@ case 168:
               }
 break;
 case 169:
-#line 1124 "parse.y"
+#line 1125 "parse.y"
 	{ yyval.ca_p = ZMALLOC(CA_REC) ;
                 yyval.ca_p->type = ST_NONE ;
                 yyval.ca_p->link = yyvsp[-2].ca_p ;
@@ -2607,20 +2606,20 @@ case 169:
               }
 break;
 case 170:
-#line 1134 "parse.y"
+#line 1135 "parse.y"
 	{ yyval.ca_p = ZMALLOC(CA_REC) ;
                 yyval.ca_p->type = CA_EXPR ;
                 yyval.ca_p->call_offset = code_offset ;
               }
 break;
 case 171:
-#line 1140 "parse.y"
+#line 1141 "parse.y"
 	{ yyval.ca_p = ZMALLOC(CA_REC) ;
                 yyval.ca_p->type = ST_NONE ;
                 code_call_id(yyval.ca_p, yyvsp[-1].stp) ;
               }
 break;
-#line 2623 "y.tab.c"
+#line 2622 "y.tab.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
