@@ -1,4 +1,3 @@
-
 /********************************************
 regexp.h
 copyright 1991, Michael D. Brennan
@@ -10,19 +9,26 @@ Mawk is distributed without warranty under the terms of
 the GNU General Public License, version 2, 1991.
 ********************************************/
 
-/*@Log: regexp.h,v @
+/*
+ * $MawkId: regexp.h,v 1.8 2009/09/13 17:26:08 tom Exp $
+ * @Log: regexp.h,v @
  * Revision 1.1.1.1  1993/07/03  18:58:19  mike
  * move source to cvs
  *
  * Revision 5.1  1991/12/05  07:59:30  brennan
  * 1.1 pre-release
  *
-*/
+ */
+#ifndef  MAWK_REPL_H
+#define  MAWK_REPL_H
 
 #include <stdio.h>
+#include "nstd.h"
 
-PTR   PROTO( REcompile , (char *) ) ;
-int   PROTO( REtest, (char *, PTR) ) ;
-char *PROTO( REmatch, (char *, PTR, unsigned *) ) ;
-void  PROTO( REmprint, (PTR , FILE*) ) ;
-char *PROTO( REerror, (void)) ;
+PTR REcompile(char *, size_t);
+int REtest(char *, unsigned, PTR);
+char *REmatch(char *, unsigned, PTR, unsigned *);
+void REmprint(PTR, FILE *);
+const char *REerror(void);
+
+#endif /*  MAWK_REPL_H */
